@@ -93,7 +93,7 @@ class FileServerConnector:
                                             headers=self._construct_headers())
         original = answer.get("original")
         if not original:
-            raise ValueError(f'Wrong answer: {original}')
+            raise ValueError(f'Wrong answer: {answer}')
         return dict_to_dataclass(original, FileLink)
 
     async def delete_file(self, file_id: str) -> FileLink:
